@@ -34,7 +34,7 @@ LOG = logging.getLogger(__name__)
 class LibvirtInspector(virt_inspector.Inspector):
 
     def __init__(self, conf):
-        super(LibvirtInspector, self).__init__(conf)
+        super().__init__(conf)
         # NOTE(sileht): create a connection on startup
         self.connection
         self.cache = {}
@@ -95,8 +95,8 @@ class LibvirtInspector(virt_inspector.Inspector):
             if fref is not None:
                 fref = fref.get('filter')
 
-            params = dict((p.get('name').lower(), p.get('value'))
-                          for p in iface.findall('filterref/parameter'))
+            params = {p.get('name').lower(): p.get('value')
+                      for p in iface.findall('filterref/parameter')}
 
             # Extract interface ID
             try:
@@ -117,9 +117,10 @@ class LibvirtInspector(virt_inspector.Inspector):
             try:
                 dom_stats = domain.interfaceStats(name)
             except libvirt.libvirtError as ex:
-                LOG.warning(_("Error from libvirt when running instanceStats, "
-                              "This may not be harmful, but please check : "
-                              "%(ex)s") % {'ex': ex})
+                LOG.warning("Error from libvirt when running instanceStats, "
+                            "This may not be harmful, but please check : "
+                            "%(ex)s",
+                            {'ex': ex})
                 continue
 
             # Retrieve previous values
@@ -139,8 +140,8 @@ class LibvirtInspector(virt_inspector.Inspector):
                 if tx_delta < 0:
                     tx_delta = dom_stats[4]
             else:
-                LOG.debug('No delta meter predecessor for %s / %s' %
-                          (instance.id, name))
+                LOG.debug('No delta meter predecessor for %s / %s',
+                          instance.id, name)
                 rx_delta = 0
                 tx_delta = 0
 
@@ -183,9 +184,9 @@ class LibvirtInspector(virt_inspector.Inspector):
             except libvirt.libvirtError as ex:
                 # raised error even if lock is acquired while live migration,
                 # even it looks normal.
-                LOG.warning(_("Error from libvirt while checking blockStats, "
-                              "This may not be harmful, but please check : "
-                              "%(ex)s") % {'ex': ex})
+                LOG.warning("Error from libvirt while checking blockStats, "
+                            "This may not be harmful, but please check : "
+                            "%(ex)s", {'ex': ex})
                 pass
 
     @libvirt_utils.retry_on_disconnect
@@ -207,10 +208,16 @@ class LibvirtInspector(virt_inspector.Inspector):
     def inspect_instance(self, instance, duration=None):
         domain = self._get_domain_not_shut_off_or_raise(instance)
 
+        memory_actual = None
+        memory_available = None
         memory_used = memory_resident = None
         memory_swap_in = memory_swap_out = None
         memory_stats = domain.memoryStats()
         # Stat provided from libvirt is in KB, converting it to MB.
+        if 'actual' in memory_stats:
+            memory_actual = memory_stats['actual'] / units.Ki
+        if 'available' in memory_stats:
+            memory_available = memory_stats['available'] / units.Ki
         if 'usable' in memory_stats and 'available' in memory_stats:
             memory_used = (memory_stats['available'] -
                            memory_stats['usable']) / units.Ki
@@ -251,6 +258,8 @@ class LibvirtInspector(virt_inspector.Inspector):
             power_state=domain.info()[0],
             cpu_number=stats.get('vcpu.current'),
             cpu_time=cpu_time,
+            memory_actual=memory_actual,
+            memory_available=memory_available,
             memory_usage=memory_used,
             memory_resident=memory_resident,
             memory_swap_in=memory_swap_in,
