@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import errno
 from oslo_config import cfg
 from oslo_log import log as logging
 import tenacity
@@ -30,7 +31,7 @@ LOG = logging.getLogger(__name__)
 OPTS = [
     cfg.StrOpt('libvirt_type',
                default='kvm',
-               choices=['kvm', 'lxc', 'qemu', 'uml'],
+               choices=['kvm', 'lxc', 'qemu', 'parallels'],
                help='Libvirt domain type.'),
     cfg.StrOpt('libvirt_uri',
                default='',
@@ -38,7 +39,9 @@ OPTS = [
                     '(which is dependent on libvirt_type).'),
 ]
 
-LIBVIRT_PER_TYPE_URIS = dict(uml='uml:///system', lxc='lxc:///')
+LIBVIRT_PER_TYPE_URIS = dict(
+    parallels='parallels:///system',
+    lxc='lxc:///')
 
 
 # We don't use the libvirt constants in case of libvirt is not available
@@ -105,11 +108,17 @@ def refresh_libvirt_connection(conf, klass):
 def is_disconnection_exception(e):
     if not libvirt:
         return False
-    return (isinstance(e, libvirt.libvirtError)
-            and e.get_error_code() in (libvirt.VIR_ERR_SYSTEM_ERROR,
-                                       libvirt.VIR_ERR_INTERNAL_ERROR)
-            and e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
-                                         libvirt.VIR_FROM_RPC))
+    if not isinstance(e, libvirt.libvirtError):
+        return False
+    is_libvirt_error = (
+        e.get_error_code() in (libvirt.VIR_ERR_SYSTEM_ERROR,
+                               libvirt.VIR_ERR_INTERNAL_ERROR)
+        and e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
+                                     libvirt.VIR_FROM_RPC))
+    is_system_error = (
+        e.get_error_domain() == libvirt.VIR_FROM_RPC
+        and e.get_error_code() == errno.EPIPE)
+    return is_libvirt_error or is_system_error
 
 
 retry_on_disconnect = tenacity.retry(
