@@ -22,7 +22,6 @@ from oslo_log import log
 from oslo_utils import netutils
 
 import ceilometer
-from ceilometer.i18n import _
 from ceilometer import publisher
 from ceilometer.publisher import utils
 
@@ -31,7 +30,7 @@ LOG = log.getLogger(__name__)
 
 class UDPPublisher(publisher.ConfigPublisherBase):
     def __init__(self, conf, parsed_url):
-        super(UDPPublisher, self).__init__(conf, parsed_url)
+        super().__init__(conf, parsed_url)
         self.host, self.port = netutils.parse_host_port(
             parsed_url.netloc, default_port=4952)
         addrinfo = None
@@ -72,7 +71,7 @@ class UDPPublisher(publisher.ConfigPublisherBase):
                 self.socket.sendto(msgpack.dumps(msg, use_bin_type=True),
                                    (self.host, self.port))
             except Exception as e:
-                LOG.warning(_("Unable to send sample over UDP"))
+                LOG.warning("Unable to send sample over UDP")
                 LOG.exception(e)
 
     def publish_events(self, events):
