@@ -11,11 +11,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""Tests for libvirt inspector.
-"""
+"""Tests for libvirt inspector."""
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_utils import units
 from oslotest import base
 
@@ -29,7 +28,7 @@ class FakeLibvirtError(Exception):
     pass
 
 
-class VMInstance(object):
+class VMInstance:
     id = 'ff58e738-12f4-4c58-acde-77617b68da56'
     name = 'instance-00000001'
 
@@ -37,7 +36,7 @@ class VMInstance(object):
 class TestLibvirtInspection(base.BaseTestCase):
 
     def setUp(self):
-        super(TestLibvirtInspection, self).setUp()
+        super().setUp()
         conf = service.prepare_service([], [])
 
         self.instance = VMInstance()
@@ -53,7 +52,8 @@ class TestLibvirtInspection(base.BaseTestCase):
     def test_inspect_instance_stats(self):
         domain = mock.Mock()
         domain.info.return_value = (0, 0, 0, 2, 999999)
-        domain.memoryStats.return_value = {'available': 51200,
+        domain.memoryStats.return_value = {'actual': 54400,
+                                           'available': 51200,
                                            'unused': 25600,
                                            'rss': 30000,
                                            'swap_in': 5120,
@@ -68,26 +68,23 @@ class TestLibvirtInspection(base.BaseTestCase):
             'vcpu.0.wait': 10000,
             'vcpu.2.time': 10000,
             'vcpu.2.wait': 10000,
-            'perf.cmt': 90112,
             'perf.cpu_cycles': 7259361,
             'perf.instructions': 8815623,
             'perf.cache_references': 74184,
-            'perf.cache_misses': 16737,
-            'perf.mbmt': 1892352,
-            'perf.mbml': 1802240})]
+            'perf.cache_misses': 16737})]
 
         with mock.patch('ceilometer.compute.virt.libvirt.utils.'
                         'refresh_libvirt_connection', return_value=conn):
             stats = self.inspector.inspect_instance(self.instance, None)
+            self.assertEqual(0, stats.power_state)
             self.assertEqual(2, stats.cpu_number)
             self.assertEqual(40000, stats.cpu_time)
-            self.assertEqual(90112, stats.cpu_l3_cache_usage)
+            self.assertEqual(54400 / units.Ki, stats.memory_actual)
+            self.assertEqual(51200 / units.Ki, stats.memory_available)
             self.assertEqual(25600 / units.Ki, stats.memory_usage)
             self.assertEqual(30000 / units.Ki, stats.memory_resident)
             self.assertEqual(5120 / units.Ki, stats.memory_swap_in)
             self.assertEqual(8192 / units.Ki, stats.memory_swap_out)
-            self.assertEqual(1892352, stats.memory_bandwidth_total)
-            self.assertEqual(1802240, stats.memory_bandwidth_local)
             self.assertEqual(7259361, stats.cpu_cycles)
             self.assertEqual(8815623, stats.instructions)
             self.assertEqual(74184, stats.cache_references)
@@ -242,7 +239,9 @@ class TestLibvirtInspection(base.BaseTestCase):
             self.assertEqual('vnet2', vnic2.name)
             self.assertEqual('fa:16:3e:96:33:f0', vnic2.mac)
             self.assertIsNone(vnic2.fref)
-            self.assertEqual(dict(), vnic2.parameters)
+            self.assertEqual(
+                {'interfaceid': None, 'bridge': 'qbr420008b3-7c'},
+                vnic2.parameters)
             self.assertEqual(9, vnic2.rx_bytes)
             self.assertEqual(10, vnic2.rx_packets)
             self.assertEqual(11, vnic2.tx_bytes)
@@ -349,7 +348,7 @@ class TestLibvirtInspection(base.BaseTestCase):
 
             self.assertEqual(1, len(disks))
             self.assertEqual('vda', disks[0].device)
-            self.assertEqual(1, disks[0].capacity)
+            self.assertEqual(3, disks[0].capacity)
             self.assertEqual(2, disks[0].allocation)
             self.assertEqual(3, disks[0].physical)
 
@@ -469,6 +468,8 @@ class TestLibvirtInspection(base.BaseTestCase):
         with mock.patch('ceilometer.compute.virt.libvirt.utils.'
                         'refresh_libvirt_connection', return_value=conn):
             stats = self.inspector.inspect_instance(self.instance, None)
+            self.assertIsNone(stats.memory_actual)
+            self.assertIsNone(stats.memory_available)
             self.assertIsNone(stats.memory_usage)
             self.assertIsNone(stats.memory_resident)
             self.assertIsNone(stats.memory_swap_in)
@@ -477,7 +478,8 @@ class TestLibvirtInspection(base.BaseTestCase):
     def test_inspect_memory_with_usable(self):
         domain = mock.Mock()
         domain.info.return_value = (0, 0, 0, 2, 999999)
-        domain.memoryStats.return_value = {'available': 76800,
+        domain.memoryStats.return_value = {'actual': 80000,
+                                           'available': 76800,
                                            'rss': 30000,
                                            'swap_in': 5120,
                                            'swap_out': 8192,
@@ -490,6 +492,8 @@ class TestLibvirtInspection(base.BaseTestCase):
         with mock.patch('ceilometer.compute.virt.libvirt.utils.'
                         'refresh_libvirt_connection', return_value=conn):
             stats = self.inspector.inspect_instance(self.instance, None)
+            self.assertEqual(80000 / units.Ki, stats.memory_actual)
+            self.assertEqual(76800 / units.Ki, stats.memory_available)
             self.assertEqual(25600 / units.Ki, stats.memory_usage)
             self.assertEqual(30000 / units.Ki, stats.memory_resident)
             self.assertEqual(5120 / units.Ki, stats.memory_swap_in)
@@ -508,9 +512,6 @@ class TestLibvirtInspection(base.BaseTestCase):
         with mock.patch('ceilometer.compute.virt.libvirt.utils.'
                         'refresh_libvirt_connection', return_value=conn):
             stats = self.inspector.inspect_instance(self.instance, None)
-            self.assertIsNone(stats.cpu_l3_cache_usage)
-            self.assertIsNone(stats.memory_bandwidth_total)
-            self.assertIsNone(stats.memory_bandwidth_local)
             self.assertIsNone(stats.cpu_cycles)
             self.assertIsNone(stats.instructions)
             self.assertIsNone(stats.cache_references)
@@ -520,7 +521,7 @@ class TestLibvirtInspection(base.BaseTestCase):
 class TestLibvirtInspectionWithError(base.BaseTestCase):
 
     def setUp(self):
-        super(TestLibvirtInspectionWithError, self).setUp()
+        super().setUp()
         conf = service.prepare_service([], [])
         self.useFixture(fixtures.MonkeyPatch(
             'ceilometer.compute.virt.libvirt.utils.'
