@@ -17,7 +17,6 @@ import datetime
 from unittest import mock
 
 import jsonpath_rw_ext
-import six
 
 from ceilometer import declarative
 from ceilometer.event import converter
@@ -37,22 +36,23 @@ class ConverterBase(base.BaseTestCase):
                     )
 
     def assertIsValidEvent(self, event, notification):
-        self.assertIsNot(
-            None, event,
+        self.assertIsNotNone(
+            event,
             "Notification dropped unexpectedly:"
             " %s" % str(notification))
         self.assertIsInstance(event, models.Event)
 
     def assertIsNotValidEvent(self, event, notification):
-        self.assertIs(
-            None, event,
+        self.assertIsNone(
+            event,
             "Notification NOT dropped when expected to be dropped:"
             " %s" % str(notification))
 
     def assertHasTrait(self, event, name, value=None, dtype=None):
         traits = [trait for trait in event.traits if trait.name == name]
-        self.assertGreater(len(traits), 0,
-                           "Trait %s not found in event %s" % (name, event))
+        self.assertGreater(
+            len(traits), 0,
+            "Trait {} not found in event {}".format(name, event))
         trait = traits[0]
         if value is not None:
             self.assertEqual(value, trait.value)
@@ -65,13 +65,13 @@ class ConverterBase(base.BaseTestCase):
             elif dtype == models.Trait.DATETIME_TYPE:
                 self.assertIsInstance(trait.value, datetime.datetime)
             elif dtype == models.Trait.TEXT_TYPE:
-                self.assertIsInstance(trait.value, six.string_types)
+                self.assertIsInstance(trait.value, str)
 
     def assertDoesNotHaveTrait(self, event, name):
         traits = [trait for trait in event.traits if trait.name == name]
         self.assertEqual(
             len(traits), 0,
-            "Extra Trait %s found in event %s" % (name, event))
+            "Extra Trait {} found in event {}".format(name, event))
 
     def assertHasDefaultTraits(self, event):
         text = models.Trait.TEXT_TYPE
@@ -87,13 +87,13 @@ class ConverterBase(base.BaseTestCase):
 
     def assertPathsEqual(self, path1, path2):
         self.assertTrue(self._cmp_tree(path1, path2),
-                        'JSONPaths not equivalent %s %s' % (path1, path2))
+                        'JSONPaths not equivalent {} {}'.format(path1, path2))
 
 
 class TestTraitDefinition(ConverterBase):
 
     def setUp(self):
-        super(TestTraitDefinition, self).setUp()
+        super().setUp()
         self.n1 = self._create_test_notification(
             "test.thing",
             "uuid-for-notif-0001",
@@ -362,7 +362,7 @@ class TestTraitDefinition(ConverterBase):
 class TestEventDefinition(ConverterBase):
 
     def setUp(self):
-        super(TestEventDefinition, self).setUp()
+        super().setUp()
 
         self.traits_cfg = {
             'instance_id': {
@@ -573,7 +573,7 @@ class TestEventDefinition(ConverterBase):
 class TestNotificationConverter(ConverterBase):
 
     def setUp(self):
-        super(TestNotificationConverter, self).setUp()
+        super().setUp()
         self.CONF = ceilometer_service.prepare_service([], [])
         self.valid_event_def1 = [{
             'event_type': 'compute.instance.create.*',
