@@ -18,12 +18,14 @@
 """Tests for ceilometer agent manager"""
 import copy
 import datetime
+import multiprocessing
 import shutil
 import tempfile
 from unittest import mock
 
 import fixtures
 from keystoneauth1 import exceptions as ka_exceptions
+from oslo_utils import timeutils
 from stevedore import extension
 
 from ceilometer.compute import discovery as nova_discover
@@ -47,7 +49,7 @@ def default_test_data(name='test'):
         user_id='test',
         project_id='test',
         resource_id='test_run_tasks',
-        timestamp=datetime.datetime.utcnow().isoformat(),
+        timestamp=timeutils.utcnow().isoformat(),
         resource_metadata={'name': 'Pollster'})
 
 
@@ -80,7 +82,7 @@ class TestPollsterBuilder(TestPollster):
 
 class TestManager(base.BaseTestCase):
     def setUp(self):
-        super(TestManager, self).setUp()
+        super().setUp()
         self.conf = service.prepare_service([], [])
 
     def test_hash_of_set(self):
@@ -92,53 +94,29 @@ class TestManager(base.BaseTestCase):
         self.assertNotEqual(manager.hash_of_set(y), manager.hash_of_set(z))
 
     def test_load_plugins(self):
-        mgr = manager.AgentManager(0, self.conf)
+        mgr = manager.AgentManager(0, self.conf,
+                                   queue=multiprocessing.Queue())
         self.assertIsNotNone(list(mgr.extensions))
 
-    # Test plugin load behavior based on Node Manager pollsters.
-    @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
-                mock.Mock(return_value=None))
     @mock.patch('ceilometer.ipmi.pollsters.sensor.SensorPollster.__init__',
                 mock.Mock(return_value=None))
     def test_load_normal_plugins(self):
-        mgr = manager.AgentManager(0, self.conf,
-                                   namespaces=['ipmi'])
-        # 8 pollsters for Node Manager
-        self.assertEqual(13, len(mgr.extensions))
-
-    # Skip loading pollster upon ExtensionLoadError
-    @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
-                mock.Mock(side_effect=plugin_base.ExtensionLoadError(
-                    'NodeManager not supported on host')))
-    @mock.patch('ceilometer.polling.manager.LOG')
-    def test_load_failed_plugins(self, LOG):
-        # Here we additionally check that namespaces will be converted to the
-        # list if param was not set as a list.
-        manager.AgentManager(0, self.conf, namespaces='ipmi')
-        err_msg = 'Skip loading extension for %s: %s'
-        pollster_names = [
-            'power', 'temperature', 'outlet_temperature',
-            'airflow', 'cups', 'cpu_util', 'mem_util', 'io_util']
-        calls = [mock.call(err_msg, 'hardware.ipmi.node.%s' % n,
-                           'NodeManager not supported on host')
-                 for n in pollster_names]
-        LOG.debug.assert_has_calls(calls=calls[:2], any_order=True)
+        mgr = manager.AgentManager(0, self.conf, namespaces=['ipmi'],
+                                   queue=multiprocessing.Queue())
+        self.assertEqual(5, len(mgr.extensions))
 
     # Skip loading pollster upon ImportError
-    @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
-                mock.Mock(side_effect=ImportError))
     @mock.patch('ceilometer.ipmi.pollsters.sensor.SensorPollster.__init__',
                 mock.Mock(side_effect=ImportError))
     @mock.patch('ceilometer.polling.manager.LOG')
     def test_import_error_in_plugin(self, LOG):
         namespaces = ['ipmi']
-        manager.AgentManager(0, self.conf, namespaces=namespaces)
+        manager.AgentManager(0, self.conf, namespaces=namespaces,
+                             queue=multiprocessing.Queue())
         LOG.warning.assert_called_with(
             'No valid pollsters can be loaded from %s namespaces', namespaces)
 
     # Exceptions other than ExtensionLoadError are propagated
-    @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
-                mock.Mock(side_effect=PollingException))
     @mock.patch('ceilometer.ipmi.pollsters.sensor.SensorPollster.__init__',
                 mock.Mock(side_effect=PollingException))
     def test_load_exceptional_plugins(self):
@@ -192,7 +170,7 @@ class BatchTestPollster(TestPollster):
         self.resources.extend(resources)
         for resource in resources:
             c = copy.deepcopy(self.test_data)
-            c.timestamp = datetime.datetime.utcnow().isoformat()
+            c.timestamp = timeutils.utcnow().isoformat()
             c.resource_id = resource
             c.resource_metadata['resource'] = resource
             yield c
@@ -209,7 +187,7 @@ class TestPollsterPollingException(TestPollster):
     polling_failures = 0
 
     def get_samples(self, manager, cache, resources):
-        func = super(TestPollsterPollingException, self).get_samples
+        func = super().get_samples
         sample = func(manager=manager,
                       cache=cache,
                       resources=resources)
@@ -276,13 +254,17 @@ class BaseAgent(base.BaseTestCase):
     class DiscoveryException(TestDiscoveryException):
         params = []
 
-    def setup_polling(self, poll_cfg=None):
+    def setup_polling(self, poll_cfg=None, override_conf=None):
         name = self.cfg2file(poll_cfg or self.polling_cfg)
-        self.CONF.set_override('cfg_file', name, group='polling')
-        self.mgr.polling_manager = manager.PollingManager(self.CONF)
+
+        conf_to_use = override_conf or self.CONF
+
+        conf_to_use.set_override('cfg_file', name, group='polling')
+        self.mgr.polling_manager = manager.PollingManager(conf_to_use)
 
     def create_manager(self):
-        return manager.AgentManager(0, self.CONF)
+        queue = multiprocessing.Queue()
+        return manager.AgentManager(0, self.CONF, queue=queue)
 
     def fake_notifier_sample(self, ctxt, event_type, payload):
         for m in payload['samples']:
@@ -290,7 +272,7 @@ class BaseAgent(base.BaseTestCase):
             self.notified_samples.append(m)
 
     def setUp(self):
-        super(BaseAgent, self).setUp()
+        super().setUp()
         self.notified_samples = []
         self.notifier = mock.Mock()
         self.notifier.sample.side_effect = self.fake_notifier_sample
@@ -301,7 +283,8 @@ class BaseAgent(base.BaseTestCase):
         self.CONF = service.prepare_service([], [])
         self.CONF.set_override(
             'cfg_file',
-            self.path_get('etc/ceilometer/polling_all.yaml'), group='polling'
+            self.path_get('etc/ceilometer/polling_all.yaml'),
+            group='polling'
         )
         self.polling_cfg = {
             'sources': [{
@@ -327,7 +310,7 @@ class BaseAgent(base.BaseTestCase):
         self.DiscoveryException.params = []
         self.Discovery.resources = []
         self.DiscoveryAnother.resources = []
-        super(BaseAgent, self).tearDown()
+        super().tearDown()
 
     def create_extension_list(self):
         return [extension.Extension('test',
@@ -377,7 +360,7 @@ class BaseAgent(base.BaseTestCase):
 class TestPollingAgent(BaseAgent):
 
     def setUp(self):
-        super(TestPollingAgent, self).setUp()
+        super().setUp()
         self.mgr = self.create_manager()
         self.mgr.extensions = self.create_extension_list()
         ks_client = mock.Mock(auth_token='fake_token')
@@ -703,6 +686,34 @@ class TestPollingAgent(BaseAgent):
             mock.call('Finished polling pollster %(poll)s in the context '
                       'of %(src)s', {'poll': 'test', 'src': 'test_polling'})
         ])
+        LOG.debug.assert_has_calls([
+            mock.call('Polster heartbeat update: test')
+        ])
+
+    @mock.patch('ceilometer.polling.manager.LOG')
+    def test_polling_and_notify_with_resources_with_threads(self, log_mock):
+        conf_to_use = self.CONF
+        conf_to_use.set_override(
+            'threads_to_process_pollsters', 4, group='polling')
+
+        self.setup_polling(override_conf=conf_to_use)
+
+        polling_task = list(self.mgr.setup_polling_tasks().values())[0]
+        polling_task.poll_and_notify()
+
+        log_mock.info.assert_has_calls([
+            mock.call('Polling pollster %(poll)s in the context of %(src)s',
+                      {'poll': 'test', 'src': 'test_polling'}),
+            mock.call('Finished polling pollster %(poll)s in the context '
+                      'of %(src)s', {'poll': 'test', 'src': 'test_polling'})
+        ])
+        log_mock.debug.assert_has_calls([
+            mock.call('Polster heartbeat update: test')
+        ])
+
+        # Even though we enabled 4 threads, we have only one metric configured.
+        # Therefore, there should be only one call here.
+        self.assertEqual(1, polling_task.manager.notifier.sample.call_count)
 
     @mock.patch('ceilometer.polling.manager.LOG')
     def test_skip_polling_and_notify_with_no_resources(self, LOG):
@@ -711,9 +722,9 @@ class TestPollingAgent(BaseAgent):
         polling_task = list(self.mgr.setup_polling_tasks().values())[0]
         pollster = list(polling_task.pollster_matches['test_polling'])[0]
         polling_task.poll_and_notify()
-        LOG.debug.assert_called_with(
-            'Skip pollster %(name)s, no %(p_context)s resources found this '
-            'cycle', {'name': pollster.name, 'p_context': ''})
+        LOG.debug.assert_has_calls([mock.call(
+            'Skip pollster %(name)s, no %(p_context)s resources found '
+            'this cycle', {'name': pollster.name, 'p_context': ''})])
 
     @mock.patch('ceilometer.polling.manager.LOG')
     def test_skip_polling_polled_resources(self, LOG):
@@ -726,9 +737,9 @@ class TestPollingAgent(BaseAgent):
         self.setup_polling()
         polling_task = list(self.mgr.setup_polling_tasks().values())[0]
         polling_task.poll_and_notify()
-        LOG.debug.assert_called_with(
-            'Skip pollster %(name)s, no %(p_context)s resources found this '
-            'cycle', {'name': 'test', 'p_context': 'new '})
+        LOG.debug.assert_has_calls([mock.call(
+            'Skip pollster %(name)s, no %(p_context)s resources found '
+            'this cycle', {'name': 'test', 'p_context': 'new'})])
 
     @mock.patch('oslo_utils.timeutils.utcnow')
     def test_polling_samples_timestamp(self, mock_utc):
@@ -870,7 +881,7 @@ class TestPollingAgent(BaseAgent):
 class TestPollingAgentPartitioned(BaseAgent):
 
     def setUp(self):
-        super(TestPollingAgentPartitioned, self).setUp()
+        super().setUp()
         self.tempdir = tempfile.mkdtemp()
         self.CONF.set_override("backend_url", "file://%s" % self.tempdir,
                                "coordination")
