@@ -200,7 +200,7 @@ SNAPSHOT_TRANSFER_ACCEPT_END = models.Event(
 class PublisherTest(base.BaseTestCase):
 
     def setUp(self):
-        super(PublisherTest, self).setUp()
+        super().setUp()
         conf = ceilometer_service.prepare_service(argv=[], config_files=[])
         self.conf = self.useFixture(config_fixture.Config(conf))
         self.resource_id = str(uuid.uuid4())
@@ -339,9 +339,11 @@ class PublisherTest(base.BaseTestCase):
     def test_activity_gnocchi_project_not_found(self, logger):
         self.ks_client.projects.find.side_effect = ka_exceptions.NotFound
         self._do_test_activity_filter(2)
-        logger.warning.assert_called_with(
+        log_called_args = logger.warning.call_args_list
+        self.assertEqual(
             'Filtered project [service] not found in keystone, ignoring the '
-            'filter_project option')
+            'filter_project option',
+            log_called_args[0][0][0] % log_called_args[0][0][1])
 
     @mock.patch('ceilometer.publisher.gnocchi.GnocchiPublisher'
                 '._get_gnocchi_client')
@@ -445,9 +447,9 @@ class MockResponse(mock.NonCallableMock):
                 204: 'Created',
                 409: 'Conflict',
                 }.get(code)
-        super(MockResponse, self).__init__(spec=requests.Response,
-                                           status_code=code,
-                                           text=text)
+        super().__init__(spec=requests.Response,
+                         status_code=code,
+                         text=text)
 
 
 class PublisherWorkflowTest(base.BaseTestCase,
@@ -591,7 +593,7 @@ class PublisherWorkflowTest(base.BaseTestCase,
                                                          workflow_scenarios)
 
     def setUp(self):
-        super(PublisherWorkflowTest, self).setUp()
+        super().setUp()
         conf = ceilometer_service.prepare_service(argv=[], config_files=[])
         self.conf = self.useFixture(config_fixture.Config(conf))
         ks_client = mock.Mock()
